class GGJPawn extends UDKPawn;

var float CamOffsetDistance; //distance to offset the camera from the player in unreal units
var float CamMinDistance, CamMaxDistance;
var float CamZoomTick; //how far to zoom in/out per command
var float CamHeight; //how high cam is relative to pawn pelvis
var AnimNodeBlend MoveNode;
var AnimNodeBlend GrabIdleBlend;
var SkeletalMeshComponent TimChar;
var PointLightComponent FL;

function Idle()
{
    MoveNode = AnimNodeBlend(TimChar.FindAnimNode('GrabIdleBlend'));
    MoveNode.SetBlendTarget(0, 0.2);  
}

function Grab()
{
    GrabIdleBlend = AnimNodeBlend(TimChar.FindAnimNode('GrabIdleBlend'));
    GrabIdleBlend.SetBlendTarget(1,0.2);
}


simulated event PreBeginPlay()
{
    local GGJTimsLight L;
    Super.PostBeginPlay();
    L = Spawn(class'GGJTimsLight',,, vect(34,1186,86190), rot(0, 0, 0), ,true );
    L.isCollected();
}

//PAWN Info

simulated function FaceRotation(rotator NewRotation, float DeltaTime)
{
    // Do not update Pawn's rotation if no accel
    if (Normal(Acceleration)!=vect(0,0,0))
    {
        //Only apply rotation when falling or walking
        if ( (Physics == PHYS_Walking) || (Physics == PHYS_Falling) )
        {
            //set the rotation to the acceleration
            NewRotation = rotator((Location + Normal(Acceleration))-Location);
            NewRotation.Pitch = 0;
        }
        NewRotation = RLerp(Rotation,NewRotation,0.03,true);
        //apply rotation
        SetRotation(NewRotation);
    }
}  

//orbit cam, follows player controller rotation
simulated function bool CalcCamera( float fDeltaTime, out vector out_CamLoc, out rotator out_CamRot, out float out_FOV )
{
    local vector HitLoc,HitNorm, End, Start, vecCamHeight;

    vecCamHeight = vect(0,0,0);
    vecCamHeight.Z = CamHeight;
    Start = Location;
    End = (Location+vecCamHeight)-(Vector(Controller.Rotation) * CamOffsetDistance);  //cam follow behind player controller
    out_CamLoc = End;

    //trace to check if cam running into wall/floor
    if(Trace(HitLoc,HitNorm,End,Start,false,vect(12,12,12))!=none)
    {
        out_CamLoc = HitLoc + vecCamHeight;
    }
    
    //camera will look slightly above player
   out_CamRot=rotator((Location + vecCamHeight) - out_CamLoc);
   return true;
}


defaultproperties
{
    GroundSpeed=550.0
    JumpZ=502.0
    CamHeight = 40.0
    CamMinDistance = 40.0
    CamMaxDistance = 400.0
    CamOffsetDistance=300.0
    CamZoomTick=20.0  
    MaxJumpHeight=1250.0
    Begin Object Class=DynamicLightEnvironmentComponent Name=MyLightEnvironment
        bSynthesizeSHLight=true
        bIsCharacterLightEnvironment=true
        bUseBooleanEnvironmentShadowing=false
        
    End Object
    Components.Add(MyLightEnvironment)
    
    Begin Object Class=PointLightComponent Name=frontLight
        
    End Object
    
     
   begin object class=SkeletalMeshComponent Name=Model3D       
      SkeletalMesh=SkeletalMesh'GGJ-TimChar.Meshes.Tim_01'
      AnimSets(0)=AnimSet'GGJ-TimChar.AnimSets.TimCharAnimset'
      AnimtreeTemplate=AnimTree'GGJ-TimChar.AnimTree.TimChar_AnimTree'
      LightEnvironment=MyLightEnvironment
      bCastDynamicShadow=true
      bAcceptsLights=true
      CastShadow=true
      Scale=2.5
      Translation=(Z=-80.0)
   end object
  
   Begin Object Class=CylinderComponent Name=CylinderComp
        CollisionRadius=32
        CollisionHeight=76
        CollideActors=true        
        BlockActors=false
    End Object
    Components.Add(CylinderComp)
    CollisionComponent=CylinderComp
      Components.Add(Model3D)
      TimChar=Model3D
      
    Name="Default__GGJPawn"
}
